@@ -21,21 +21,40 @@
 #ifndef _GIAC_FIRST_H_
 #define _GIAC_FIRST_H_
 
-#ifdef NUMWORKS
+#if __cplusplus >= 201103L || (defined(_MSVC_LANG) && _MSVC_LANG >= 201103L)
+// post-c++11 functional headers changes, thanks to George Huebner
+#define CPP11
+#endif
+  
+// register is deprecated in c++17
+#define register 
+
+
+#ifdef _GLIBCXX_ASSERTIONS
+#undef _GLIBCXX_ASSERTIONS
+#endif
+
+#if defined NUMWORKS && !defined SDL_KHICAS
 #define KHICAS 1
+#ifdef NUMWORKS_SLOTBFR
+#define NUMWORKS_SLOTB
+#endif
+#ifdef NUMWORKS_SLOTBEN
+#define NUMWORKS_SLOTB
+#endif
 #endif
 
 #ifndef GIAC_VERSION
 #define GIAC_VERSION VERSION
 #endif
 //#include <stdint.h>
-#include <tuple>
 
 // mingw now defines x86_64
 #if (defined(__x86_64__) || defined(__arm64__)) && !defined __MINGW_H
 #define x86_64 1
 #else
 #ifdef __MINGW_H
+ 
 #define MINGW32
 #ifndef M_LN2
 #define M_LN2 0.693147180559945310
@@ -97,6 +116,7 @@
 
 #define MAX_INTSTACK 32768 // maximal size for allocating an array by int tab[]
 
+
 #ifdef FXCG
 #define RAND_MAX 2147483647
 #define clock() 0
@@ -173,8 +193,8 @@ typedef double giac_double;
 typedef long double  long_double;
 
 // sprintf replacement
-// calls snprintf instead of sprintf with n=256, assumes s bufsize>=256
-int sprintf256(char *s,const char *format,...);
+// calls snprintf instead of sprintf with n=512, assumes s bufsize>=512
+int sprintf512(char *s,const char *format,...);
 int my_sprintf(char * s, const char * format, ...);
 #ifdef GIAC_HAS_STO_38
 //#define WITH_MYOSTREAM
@@ -183,7 +203,7 @@ int my_sprintf(char * s, const char * format, ...);
 #ifdef WITH_MYOSTREAM
 #include "myostream.h"
 #else
-#if defined KHICAS //&& defined STATIC_BUILTIN_LEXER_FUNCTION
+#if defined KHICAS || defined SDL_KHICAS //&& defined STATIC_BUILTIN_LEXER_FUNCTION
 #include "stdstream"
 #define my_ostream stdostream
 #else
@@ -619,4 +639,8 @@ namespace ustl {
 }
 #endif
 
+//#ifdef __MINGW_H
+#undef RAND_MAX
+#define RAND_MAX 2147483647
+//#endif
 #endif // _GIAC_FIRST_H_
